@@ -845,7 +845,7 @@ fetch_update_process (CCCHHDoorIsDesktopWidget *self, dooris_state_t new_state,
 		self->current_state = DOORIS_FNORD;
 	}
 
-	if (new_state == self->last_state) {
+	if (self->current_state == self->last_state) {
 		g_debug(WIDGET_NAME": state unchanged");
 
 		// button sets force_banner, display current state even if unchanged
